==> eslint-plugin-angular-0.1.2.tgz: package/test/ng_typecheck_array.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var eslint = require('../node_modules/eslint/lib/eslint'),
    ESLintTester = require('eslint-tester');

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new ESLintTester(eslint);
eslintTester.addRuleTest('rules/ng_typecheck_array', {
    valid: [
        'angular.isArray([])'
    ],
    invalid: [
        { code: 'Object.prototype.toString.call([]) === "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" === Object.prototype.toString.call([])', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'variable === "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" === variable', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'Object.prototype.toString.call([]) !== "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" !== typeof []', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'variable !== "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" !== variable', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'Array.isArray(variable)', errors: [{ message: 'You should use the angular.isArray method'}] }
    ]
});

==> eslint-plugin-angular-0.6.1.tgz: package/test/ng_typecheck_array.js <==
//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

var rule = require('../rules/ng_typecheck_array'),
    RuleTester = require("eslint").RuleTester;

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

var eslintTester = new RuleTester();
eslintTester.run('ng_typecheck_array', rule, {
    valid: [
        'angular.isArray([])'
    ],
    invalid: [
        { code: 'Object.prototype.toString.call([]) === "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" === Object.prototype.toString.call([])', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'variable === "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" === variable', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'Object.prototype.toString.call([]) !== "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" !== typeof []', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'variable !== "[object Array]"', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: '"[object Array]" !== variable', errors: [{ message: 'You should use the angular.isArray method'}] },
        { code: 'Array.isArray(variable)', errors: [{ message: 'You should use the angular.isArray method'}] }
    ]
});
